@@ -11,6 +11,7 @@ import (
 
 	jc "github.com/juju/testing/checkers"
 	"github.com/juju/utils"
+	"github.com/juju/utils/series"
 	"github.com/juju/utils/set"
 	gc "gopkg.in/check.v1"
 
@@ -28,7 +29,7 @@ import (
 )
 
 // toolsLtsSeries records the known Ubuntu LTS series.
-var toolsLtsSeries = []string{"precise", "trusty"}
+var toolsLtsSeries = series.SupportedLts()
 
 // ToolsFixture is used as a fixture to stub out the default tools URL so we
 // don't hit the real internet during tests.
@@ -232,7 +233,7 @@ func uploadFakeTools(stor storage.Storage, toolsDir, stream string) error {
 
 // UploadFakeTools puts fake tools into the supplied storage with a binary
 // version matching version.Current; if version.Current's series is different
-// to coretesting.FakeDefaultSeries, matching fake tools will be uploaded for that
+// to series.LatestLts(), matching fake tools will be uploaded for that
 // series.  This is useful for tests that are kinda casual about specifying
 // their environment.
 func UploadFakeTools(c *gc.C, stor storage.Storage, toolsDir, stream string) {
@@ -253,7 +254,7 @@ func RemoveFakeTools(c *gc.C, stor storage.Storage, toolsDir string) {
 	name := envtools.StorageName(toolsVersion, toolsDir)
 	err := stor.Remove(name)
 	c.Check(err, jc.ErrorIsNil)
-	defaultSeries := coretesting.FakeDefaultSeries
+	defaultSeries := series.LatestLts()
 	if version.Current.Series != defaultSeries {
 		toolsVersion.Series = defaultSeries
 		name := envtools.StorageName(toolsVersion, toolsDir)
