@@ -27,11 +27,6 @@ func stateStepsFor118() []Step {
 // stepsFor118 returns upgrade steps for Juju 1.18 that operate via the API.
 func stepsFor118() []Step {
 	return []Step{
-		&upgradeStep{
-			description: "make $DATADIR/locks owned by ubuntu:ubuntu",
-			targets:     []Target{AllMachines},
-			run:         ensureLockDirExistsAndUbuntuWritable,
-		},
 		&upgradeStep{
 			description: "generate system ssh key",
 			targets:     []Target{StateServer},
