@@ -16,6 +16,7 @@ import (
 	"time"
 
 	"github.com/juju/errors"
+	"github.com/juju/mutex"
 	jc "github.com/juju/testing/checkers"
 	ft "github.com/juju/testing/filetesting"
 	"github.com/juju/utils/clock"
@@ -78,7 +79,7 @@ func (s *UniterSuite) SetUpSuite(c *gc.C) {
 	state.GetClock = func() clock.Clock {
 		return leaseClock
 	}
-	s.AddSuiteCleanup(func(*gc.C) { state.GetClock = oldGetClock })
+	s.AddCleanup(func(*gc.C) { state.GetClock = oldGetClock })
 }
 
 func (s *UniterSuite) TearDownSuite(c *gc.C) {
@@ -407,23 +408,19 @@ func (s *UniterSuite) TestUniterConfigChangedHook(c *gc.C) {
 }
 
 func (s *UniterSuite) TestUniterHookSynchronisation(c *gc.C) {
+	var lock hookLock
 	s.runUniterTests(c, []uniterTest{
 		ut(
 			"verify config change hook not run while lock held",
 			quickStart{},
-			acquireHookSyncLock{},
+			lock.acquire(),
 			changeConfig{"blog-title": "Goodness Gracious Me"},
 			waitHooks{},
-			releaseHookSyncLock,
+			lock.release(),
 			waitHooks{"config-changed"},
-		), ut(
-			"verify held lock by this unit is broken",
-			acquireHookSyncLock{"u/0:fake"},
-			quickStart{},
-			verifyHookSyncLockUnlocked,
 		), ut(
 			"verify held lock by another unit is not broken",
-			acquireHookSyncLock{"u/1:fake"},
+			lock.acquire(),
 			// Can't use quickstart as it has a built in waitHooks.
 			createCharm{},
 			serveCharm{},
@@ -432,8 +429,7 @@ func (s *UniterSuite) TestUniterHookSynchronisation(c *gc.C) {
 			startUniter{},
 			waitAddresses{},
 			waitHooks{},
-			verifyHookSyncLockLocked,
-			releaseHookSyncLock,
+			lock.release(),
 			waitUnitAgent{status: params.StatusIdle},
 			waitHooks{"install", "leader-elected", "config-changed", "start"},
 		),
@@ -2255,7 +2251,7 @@ func (m *mockExecutor) Run(op operation.Operation) error {
 }
 
 func (s *UniterSuite) TestOperationErrorReported(c *gc.C) {
-	executorFunc := func(stateFilePath string, getInstallCharm func() (*corecharm.URL, error), acquireLock func(string) (func() error, error)) (operation.Executor, error) {
+	executorFunc := func(stateFilePath string, getInstallCharm func() (*corecharm.URL, error), acquireLock func() (mutex.Releaser, error)) (operation.Executor, error) {
 		e, err := operation.NewExecutor(stateFilePath, getInstallCharm, acquireLock)
 		c.Assert(err, jc.ErrorIsNil)
 		return &mockExecutor{e}, nil
